@@ -1,6 +1,6 @@
 package Bundle::TraqNet;
 
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 1;
 __END__
@@ -16,13 +16,16 @@ C<perl -MCPAN -e 'install Bundle::TraqNet'>
 
 =head1 CONTENTS
 
+Apache::DBI		- Persistance in DB - Edmund Mergl
 Apache::Cookie		- Part of libapreq, Jim Winstead 
 Apache::Request		- Part of libapreq, Jim Winstead 
+Storable		- needed by Apache::Session - Raphael Manfredi
 Apache::Session		- Session managment, Jeffrey Baker
 Date::Manip		- makes working with dates more fun then accounting systems - Sullivan Beck
 IO::File		- Graham Barr 
 MIME::Base64		- Gisle Aas 
 MIME::Entity		- Eryq
+Parse::RecDescent	- Used by IMAP client - Damian Conway
 Mail::IMAPClient	- David J. Kernen
 MIME::Types		- Mark Overmeer 
 Mail::Internet		- Mark Overmeer again
